
======================
AI问题是一个哲学问题
======================

意识能否被理解？
=================

因为逃课太多，最近被辅导员罚抄《马克思主义》。在阅读马克思主义哲学的同时，
我发现一些很有意思的问题。比如，**意识是否能被意识所理解**？

唯物主义哲学的**最基本**前提是：物质是第一性的，意识是第二性的，意识是物质的反映。

现如今，我们用意识来研究意识，用第二性研究第二性，就像用不确定性研究不确定性，
也就是说，它能够像 第二性的意识 能理解 第一性的物质 一样，能用 第二性的意识
理解 第二性的意识 吗？也就是说，第二性意识 具有 第一性的物质 的性质一样，可
被第二性理解吗？就像，概率 能描述 概率 本身吗？

如果 意识 能够被理解，那么是否应该承认 意识 与 物质 都是同等地位的，都是第一性的？

人工智能是个哲学问题
=========================

我个人觉得，人工智能本质是哲学问题，不是计算机问题。**计算机只是手段，是工具，哲学才是本质**。
在我们如此大量的依赖于计算机的同时，我们应该静下心来，思考一些哲学问题。

这个哲学问题，是一个关于认知的问题，关于心灵的问题，关于灵魂的问题，关于人类自我的问题。

哲学问题是美的问题
========================

在我阅读马克思的哲学思想的时候，真的觉得这是一种美。一种优美。阅读、理解马克思的哲学著作，
是一种享受，一种生命的升华，是一种精神的飞跃。这个世界是存在美感的。生命需要美的升华！

目前，Deep Learning的很多工作都是很粗糙的，缺乏实在的美感。我觉得，需要得到突破。

``2016-11-12``
